==> push-1.0.0-sources.jar: pl/redlink/push/service/RegisterDeviceService.kt <==
package pl.redlink.push.service

import android.content.Context
import android.content.Intent
import androidx.core.app.JobIntentService
import pl.redlink.push.Logger
import pl.redlink.push.di.RedlinkModule.pushRepository
import pl.redlink.push.manager.token.FcmTokenManager
import pl.redlink.push.provider.FirebaseTokenProvider
import pl.redlink.push.provider.RedlinkIdProvider
import pl.redlink.push.provider.UuidProvider
import pl.redlink.push.service.model.Device
import kotlinx.coroutines.runBlocking

class RegisterDeviceService : JobIntentService() {

    override fun onHandleWork(intent: Intent) {
        val force = intent.getBooleanExtra(EXTRA_FORCE, false)
        runBlocking {
            RedlinkIdProvider.getFcmProjectId()?.let { fcmProjectId ->
                val redlinkAppId = RedlinkIdProvider.getRedlinkAppId()
                val fcmToken = FirebaseTokenProvider.getFcmToken(fcmProjectId)
                val savedFcmToken = FcmTokenManager.get()
                if (fcmToken != null && (FcmTokenManager.isNewToken(fcmToken) || force)) {
                    val response = pushRepository.registerDevice(Device(
                            registrationId = fcmToken,
                            appId = redlinkAppId,
                            userId = UuidProvider.provideUuid(applicationContext)
                    ).also {
                        if (!savedFcmToken.isNullOrEmpty() && fcmToken != savedFcmToken) {
                            it.oldRegistrationId = savedFcmToken
                        }
                    })
                    if (response.isSuccess()) {
                        FcmTokenManager.put(fcmToken)
                    } else {
                        Logger.error("Device cannot be registered, please check your connection and credential keys")
                    }
                }
            }
        }
    }

    companion object {

        private const val REGISTER_DEVICE_JOB_ID = 2000
        private const val EXTRA_FORCE = "pl.redlink.push.service.EXTRA-FORCE"

        fun enqueueRequest(context: Context, force: Boolean = false) {
            val intent = Intent(context, RegisterDeviceService::class.java)
            intent.putExtra(EXTRA_FORCE, force)
            enqueueWork(context, RegisterDeviceService::class.java, REGISTER_DEVICE_JOB_ID, intent)
        }

    }

}

==> push-1.3.1-sources.jar: pl/redlink/push/service/RegisterDeviceService.kt <==
package pl.redlink.push.service

import android.content.Context
import android.content.Intent
import androidx.core.app.JobIntentService
import pl.redlink.push.Logger
import pl.redlink.push.di.RedlinkModule.pushRepository
import pl.redlink.push.manager.token.FcmTokenManager
import pl.redlink.push.provider.FirebaseTokenProvider
import pl.redlink.push.provider.RedlinkIdProvider
import pl.redlink.push.provider.UuidProvider
import pl.redlink.push.service.model.Device
import kotlinx.coroutines.runBlocking
import pl.redlink.push.extension.versionCode
import pl.redlink.push.manager.PREFS_KEY_LAST_VERSION_CODE
import pl.redlink.push.manager.PreferencesManager

class RegisterDeviceService : JobIntentService() {

    override fun onHandleWork(intent: Intent) {
        val force = intent.getBooleanExtra(EXTRA_FORCE, false)
        runBlocking {
            RedlinkIdProvider.getFcmProjectId()?.let { fcmProjectId ->
                val currentVersionCode = applicationContext.versionCode()
                val lastVersionCode = PreferencesManager.getLong(PREFS_KEY_LAST_VERSION_CODE)
                val redlinkAppId = RedlinkIdProvider.getRedlinkAppId()
                val fcmToken = FirebaseTokenProvider.getFcmToken(fcmProjectId)
                val savedFcmToken = FcmTokenManager.get()
                if (fcmToken != null && (FcmTokenManager.isNewToken(fcmToken) || force || currentVersionCode != lastVersionCode)) {
                    val response = pushRepository.registerDevice(Device(
                        registrationId = fcmToken,
                        appId = redlinkAppId,
                        userId = UuidProvider.provideUuid(applicationContext)
                    ).also {
                        if (!savedFcmToken.isNullOrEmpty() && fcmToken != savedFcmToken) {
                            it.oldRegistrationId = savedFcmToken
                        }
                    })
                    if (response.isSuccess()) {
                        FcmTokenManager.put(fcmToken)
                        PreferencesManager.put(PREFS_KEY_LAST_VERSION_CODE, applicationContext.versionCode())
                        sendDeviceRegisteredBroadcast(fcmToken)
                    } else {
                        Logger.error("Device cannot be registered, please check your connection and credential keys")
                    }
                }
            }
        }
    }

    private fun sendDeviceRegisteredBroadcast(token: String) {
        Intent().also { intent ->
            intent.action = ACTION_DEVICE_REGISTERED
            intent.putExtra(EXTRA_REGISTERED_TOKEN, token)
            sendBroadcast(intent)
        }
    }

    companion object {

        private const val REGISTER_DEVICE_JOB_ID = 2000
        private const val EXTRA_FORCE = "pl.redlink.push.service.EXTRA-FORCE"
        const val ACTION_DEVICE_REGISTERED = "pl.redlink.push.ACTION_DEVICE_REGISTERED"
        const val EXTRA_REGISTERED_TOKEN = "pl.redlink.push.EXTRA_REGISTERED_TOKEN"

        fun enqueueRequest(context: Context, force: Boolean = false) {
            val intent = Intent(context, RegisterDeviceService::class.java)
            intent.putExtra(EXTRA_FORCE, force)
            enqueueWork(context, RegisterDeviceService::class.java, REGISTER_DEVICE_JOB_ID, intent)
        }

    }

}
